@@ -33,6 +33,7 @@
 #include <Lum/Base/String.h>
 
 #include <Lum/Dlg/About.h>
+#include <Lum/Dlg/ActionDialog.h>
 #include <Lum/Dlg/Msg.h>
 
 #include <Lum/Model/Action.h>
@@ -52,11 +53,10 @@
 
 static Lum::AppInfo info;
 
-class Settings : public Lum::Dialog
+class Settings : public Lum::Dlg::ActionDialog
 {
 public:
   Settings()
-  : Dialog()
   {
     // no code
   }
@@ -66,15 +66,15 @@ public:
     // no code
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::DirNameSelect *dirSel;
     Lum::Label         *label;
     Lum::Panel         *panel;
 
-    panel=new Lum::VPanel();
+    panel=Lum::VPanel::Create(true,false);
 
-    label=new Lum::Label();
+    label=Lum::Label::Create(true,false);
 
     dirSel=new Lum::DirNameSelect();
     dirSel->SetFlex(true,false);
@@ -84,13 +84,13 @@ public:
     label->AddLabel(L"Image path:",dirSel);
 
     panel->Add(label);
-    panel->AddSpace();
-    panel->Add(Lum::ButtonRow::Create(true,false)
-               ->Add(Lum::Button::Create(L"_Close",GetClosedAction(),Lum::Button::typeDefault,true,true)));
 
-    SetMain(panel);
+    return panel;
+  }
 
-    Dialog::PreInit();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
   }
 };
 
@@ -241,9 +241,9 @@ public:
     vpanel->Add(hpanel);
     vpanel->AddSpace();
     vpanel->Add(Lum::HPanel::Create(true,false)
-                ->Add(Lum::Button::Create(L"_Prefs",settings))
+                ->Add(Lum::Button::Create(L"_Prefs...",settings))
                 ->AddSpace()
-                ->Add(Lum::Button::Create(L"_About",about))
+                ->Add(Lum::Button::Create(L"_About...",about))
                 ->AddSpace()
                 ->Add(new Lum::Text(L"Prefix:"))
                 ->AddSpace()
